;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xa1298649f07b0c451bce31dbb60d05e1 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x4b0810e5e2401731ec941feb95b49ed2 . "./code.cg2js/cg-printing.fasl")
(#xb63977602cdb1781a69b3d0439a6ec08 . "./code.cg2js/cg-caret.fasl")
(#x149da15d0dbe7f648144ae9d8520ef40 . "./code.cg2js/cg-item-list.fasl")
(#xd26038e9247b15fbff4ff6b3aece5ee7 . "./code.cg2js/cg-progress-indicator.fasl")
(#xe6abc1a168e31046e16345aab5dca0d1 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x251e46118b37f0d2ab588048ac09d901 . "./code.cg2js/cg-outline.fasl")
(#x042e3b27623951cb87f38aa16aec655b . "./code.cg2js/cg-palette.fasl")
(#xe94a1698301a9bc23c81806234b5d91a . "./code.cg2js/cg-selected-object.fasl")
(#x7c6d87e70b2e3e2b0e8e975edec68af0 . "./code.cg2js/cg-status-bar.fasl")
(#x30dd458f853868183720bad25fa9a2ad . "./code.cg2js/cg-wrap-string.fasl")
(#xb91b2402ca978cd2f3c16ac8e69636b2 . "./code.cg2js/cg-fill-texture.fasl")
(#xe8da9ddfb8b9a2177b7d25436b8f6dde . "./code.cg2js/cg-layout.fasl")
(#x42f26ccb142d9890183b76f5fcc13ea5 . "./code.cg2js/cg-timer.fasl")
(#x7e3350d3f0fa0d7d219928e7f9a3dc45 . "./code.cg2js/cg-dialog-item.fasl")
(#xffe9ce9fe4761edf19c73428611f0f29 . "./code.cg2js/cg-button.fasl")
(#xe47d43802fd3bf7ab7b75ac55e5b7caf . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x4e84fe2f374a2f5a554214439bdb1634 . "./code.cg2js/cg-tray.fasl")
(#x70e33d89f4ccc69dfc44e87a5ccede70 . "./code.cg2js/cg-plot-widget.fasl")
(#xe87ad9e69134a4a028305be26984c553 . "./code.cg2js/cg-pixmap.fasl")
(#x0e0232e2533bc2bf01ec028fe7b66cc3 . "./code.cg2js/cg-font-dialog.fasl")
(#x76076c4713b42c3f4788426747302b7b . "./code.cg2js/cg-os-widget.fasl")
(#x34e78312dee35b1b2f3a101751f8ce0d . "./code.cg2js/cg-text-or-combo.fasl")
(#xd8dec29f44c3469f54ac399ee82246f6 . "./code.cg2js/cg-trackbar.fasl")
(#xc696df994c8a77b3aa5ac4cb9a514125 . "./code.cg2js/cg-up-down-control.fasl")
(#x8970c525c47628282d26c91e0fac1100 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xb63aec0cac61f35079a037e24ede5c71 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x92b9e3301d86c61ffe14ebb6e51001a2 . "./code.cg2js/cg-intersect-posbox.fasl")
(#xe40623ff6c14c9625c0389d711571c0a . "./code.cg2js/cg-bitmap-stream.fasl")
(#xee55a0f719b2b11103f76c7a02c62874 . "./code.cg2js/cg-chart-widget.fasl")
(#x1df14f0419113c6441a3f7a9a18d66a4 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x9445258707e64b0a4c366c7d25f319d4 . "./code.cg2js/cg-group-box.fasl")
(#x5975c9c42bad1a7842e5e0d49752ef88 . "./code.cg2js/cg-static-text.fasl")
(#xa411a6ddd46f8c1ba6082f74bab8c6ea . "./code.cg2js/cg-class-slot-grid.fasl")
(#xf4f971eb1e30c810b8c85e31ef46a745 . "./code.cg2js/cg-color-dialog.fasl")
(#xea283f6203335be113ace504a31e648d . "./code.cg2js/cg-intersect.fasl")
(#x2ef7bd593ec890a237a4517c759acbfc . "./code.cg2js/cg-gesture-emulation.fasl")
(#xb0d4b4793cae0a2b8f7051aba8681168 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x4fd998fc7f67c481b41acf8e6510e68d . "./code.cg2js/cg-html-dialog.fasl")
(#x9f7c7ba3187e0478149cf9e1e300ed06 . "./code.cg2js/cg-lettered-menu.fasl")
(#xf4d3162007bdef89d712a3897e81a27a . "./code.cg2js/cg-class-grid.fasl")
(#x89a92d36e35cb85d62a779f956d30c07 . "./code.cg2js/cg-pixmap-printing.fasl")
(#xe0960198dcd98947a41bf9aef1b319a5 . "./code.cg2js/cg-calendar.fasl")
(#x6f7ea1500e1d81ce6205bd8ae3720bba . "./code.cg2js/cg-editable-text.fasl")
(#x9f53ca23b91fdffcdf8975d370c995e5 . "./code.cg2js/cg-property.fasl")
(#xf064eaae0436f93692306efe7aa805c3 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x4576f29328a156391c78c58c0fc9f32d . "./code.cg2js/cg-grid-widget.fasl")
(#x44464b97e845d0814af90f25f1c76c05 . "./code.cg2js/cg-paren-matching.fasl")
(#x23429361288f919b96116f00f76a3e2f . "./code.cg2js/cg-dev.fasl")
(#x4a0ccd206dc6814993756d152952f895 . "./code.cg2js/cg-drawable.fasl")
(#xc7770abd9abfedc12b18e5975798bb40 . "./code.cg2js/cg-curve.fasl")
(#x47dd5c22d9ea49ea182c383a9d0dc9a2 . "./code.cg2js/cg-lisp-widget.fasl")
(#xd09a8d5c983696ec5005dd5ae8150a44 . "./code.cg2js/cg-dde-utils.fasl")
(#x0fdc2d6570ed4100fd32a31c429ad02f . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x452e49e24d2bd714e8cdc602c48d157c . "./code.cg2js/cg-object-editor-layout.fasl")
(#xa789b6067b3976e3e19109548b5c7e87 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x3db48362704c8568cebda3c4858439ec . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x07bc60bfc2f877f6a5e47c6699f9b542 . "./code.cg2js/cg-lamp.fasl")
(#xb354e6c0a4a552c0433a166b6535e933 . "./code.cg2js/cg-common-control.fasl")
(#xbbcc5a5ca547e152f4411204ab6a9a0c . "./code.cg2js/cg-picture-widget-palette.fasl")
(#xb57963b322df73eceffc2d6e66fbecbe . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x8eab69d440cfa685d4d1a13fcc24498b . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x3bc18e9bc26448afd56643d947b575de . "./code.cg2js/cg-project-window.fasl")
(#xb19459c5e73e7d81c4c4c920739dfa3d . "./code.cg2js/cg-sample-file-menu.fasl")
(#xe4fd05091ea070877b63066f0ff8e377 . "./code.cg2js/cg-class-support.fasl")
(#x03718994aa1093bac6f74160cbbcdc13 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x0bf31f11f9b8c0e6f167a16f57e14953 . "./code.cg2js/cg-yes-no-list.fasl")
(#x309cd6674beb22d5e94e24561e17544b . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xe72b51c1cc86482605fbfb37da144754 . "./code.cg2js/cg-string-dialog.fasl")
(#xb927ba2be994c87b860c2c28e955b964 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x50b847b628019318030b10dfd0e2ebb6 . "./code.cg2js/cg-dropping-outline.fasl")
(#xe24e3c9b6806de7300fe83ddd40a831b . "./code.cg2js/cg.fasl")
(#xa47e7b6ec9d9379e9bc99283ce1035c5 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x4420ce24602677760e296db9dbd8dee9 . "./code.cg2js/cg-scaling-stream.fasl")
(#xb56a8d31577b079787ae14dfc8fa3561 . "./code.cg2js/cg-yes-no-string.fasl")
(#x8cefc36f2293dcd243f219de6289db91 . "./code.cg2js/cg-icon-pixmap.fasl")
(#xfd9e0bcfaf74950796d0d870d532b568 . "./code.cg2js/cg-web-browser.fasl")
(#xc76d2e12be31ac65e2e69e0758413063 . "./code.cg2js/cg-clipboard-stack.fasl")
(#xfc779bccd880e9438fcd57157373eb4e . "./code.cg2js/cg-drag-and-drop.fasl")
(#x39c5eca30bf0d20c2e48188de0b79418 . "./code.cg2js/cg-message-dialog.fasl")
(#xa24425e6fba8630e1afe61232d81506f . "./code.cg2js/cg-comtab.fasl")
(#x9b3aa9065ca2434ca1eb834a35e48418 . "./code.cg2js/cg-base.fasl")
(#x1d5eb9cb821bc0392dd278361213add7 . "./code.cg2js/cg-pixmap-widget.fasl")
(#xac433643445f650b825aa6a0a1aa2681 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x85a8653b3740c9f8d4994905027365db . "./code.cg2js/cg-text-edit-pane.fasl")
(#x2b2d611c268219ae2400a598d260c70f . "./code.cg2js/cg-utility-dialog.fasl")
(#xc4faa5ef5550f470c6a987a0907f4503 . "./code.cg2js/cg-object-editor.fasl")
(#x41a12c9ae3a8632ad79cb63a16088bc1 . "./code.cg2js/cg-edit-in-place.fasl")
(#xa7525f042fbdcb0717550f032ba6cdbc . "./code.cg2js/cg-radio-button.fasl")
(#xe557c4dffb0f4d58b9761d3540babb4d . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x40a8afb61fcd5bf2a7d7dc09462e0306 . "./code.cg2js/cg-nodes.fasl")
(#xb9f771c417c130914d0f9967360a1fa2 . "./code.cg2js/cg-get-position.fasl")
(#x1c2fdf70cc5c53926f52e7a68d36f590 . "./code.cg2js/cg-directory-dialog.fasl")
(#xa03f2f0909d5cd7e7521a8f0c2c11e92 . "./code.cg2js/cg-lisp-text.fasl")
(#x6f60f9f31ec046587b07bfd1cbeddf09 . "./code.cg2js/cg-combo-box.fasl")
(#xa6641e01629b795fca71aee53ef853dd . "./code.cg2js/cg-text-widget.fasl")
(#x3302a76006d9191db968ba05f7ed2118 . "./code.cg2js/cg-list-view.fasl")
(#x777080a0e8e4b5a362d1740c1b7ba425 . "./code.cg2js/cg-header-control.fasl")
(#x5ed12d275ed2ade4b081ca38fd278aa8 . "./code.cg2js/cg-graphics-context.fasl")
(#xeb5d1bfd2fff3706f3d8ebb160007873 . "./code.cg2js/cg-get-pixmap.fasl")
(#x55eb9100c39fcf49dc0653a95019a1df . "./code.cg2js/cg-menu.fasl")
(#x931d04f3303a57e6e9556f7054c34b2a . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x11f67b99a763805d2bb1f2c1e906eca3 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x62b9b17a12c4f75222c28c0f26f1914e . "./code.cg2js/cg-tooltip.fasl")
(#x7bd874110a1557e9ce7b5655ced11741 . "./code.cg2js/cg-html-widget.fasl")
(#x6dee69a58d7740d18c357dd025bbe4f7 . "./code.cg2js/cg-choice-list.fasl")
(#xecf73d0edebad6aea5968e42379e3f58 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x563d3fb362e8c4c1fa24569270814202 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xce114329c6cc061a3cdcf3244a864cb5 . "./code.cg2js/cg-icon.fasl")
(#x3ac2f3b02a55fa6562b0b77ad492bdef . "./code.cg2js/cg-acache.fasl")
(#x1e9d11074125fcf2f31136398ddd5071 . "./code.cg2js/cg-template-string.fasl")
(#xd38d8adbeb6271db2e4ed6f8c010612e . "./code.cg2js/cg-bitmap-pane.fasl")
(#xf277eb0d292c15720095cc96bdb26916 . "./code.cg2js/cg-toggling-widget.fasl")
(#xbb71d8e951aa626f73c7528165eab7a5 . "./code.cg2js/cg-tab-control.fasl")
(#x1a2e1c8803e3a718e218eefb73239d12 . "./code.cg2js/cg-split-bar.fasl")
(#xb664ec48c3233391dffe2308b0fbc151 . "./code.cg2js/cg-picture-widget.fasl")
(#xaf36ed8a131d9e169737c97d899181c0 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#xeb834383511081139f3685e30d54c0be . "./code.cg2js/cg-choose-printer.fasl")
(#xbd919be20ee9ba169de40472292ce162 . "./code.cg2js/cg-os-window.fasl")
(#x947d50f624be471f780dd0151a9e711a . "./code.cg2js/cg-scroll-bar.fasl")
(#x21a5a52698c5dd3de4bfaeb45f0f7919 . "./code.cg2js/cg-clipboard.fasl")
(#x44b80f55a13a20bc61d0b468d6c76e44 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x01fecf2847715e93203948de33dccbac . "./code.cg2js/cg-hotspot.fasl")
(#x8a1bbf7590d5105f5705b8adfe5fcd56 . "./code.cg2js/cg-rich-edit.fasl")
(#x9284a9d3cb19abea3e7c97fae8dbd3f5 . "./code.cg2js/cg-check-box.fasl")
(#x1193feee68193c804b8cac75795171f0 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x41afd239867b1c37e9b2d27f7e2bedd2 . "./code.cg2js/cg-file-dialog.fasl")
(#x0c807c10cfa18ca4e964ac8214bbd03b . "./code.cg2js/cg-toolbar.fasl")
(#xd214eaaa00c4662bf81442f0d153c8bd . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x90f10d4de7a58e7021f3079a8e8f0bbb . "./code.cg2js/cg-chart-or-plot.fasl")
(#xda2fdeb83f1c83148326f1a36e42bbea . "./code.cg2js/cg-shortcut-menu.fasl")
(#x0737e7354363ed66b503ecddec0e183d . "./code.idejs/ide-project.fasl")
(#xe1a56a7c7ad33b2122a8709818884a0a . "./code.idejs/ide-intro.fasl")
(#x17b8ab9b1cf97ef77e8235b54511c3db . "./code.idejs/ide-find-in-files.fasl")
(#x322ab7142b664741d246b1b6dc1339b9 . "./code.idejs/ide-grapher.fasl")
(#xfb9de51fca51533c02e939f1c681b9ed . "./code.idejs/ide-inspector.fasl")
(#x8f7e559ced6742f1712cae03f028053b . "./code.idejs/ide-editor.fasl")
(#x345691e16b38e06b3b49c42a0cdc4a23 . "./code.idejs/ide-window-list.fasl")
(#xebf539b7ae155740de0ef6235b103309 . "./code.idejs/ide-process-browser.fasl")
(#x7ad4b2c00a8b63a9ea85f22acf6fb145 . "./code.idejs/ide-patch-dialog.fasl")
(#xcec4f0d7a430e87cb08b8bce29d630ec . "./code.idejs/ide-class-grapher.fasl")
(#xfff0d7d2c9378d0d2ed13b1acd78cfe8 . "./code.idejs/ide-base.fasl")
(#x789ca7c186fff5edf2ab7bbe4394474b . "./code.idejs/ide.fasl")
(#x9429f55dbceffb407401a51295f7a00a . "./code.idejs/ide-trace.fasl")
(#x9e8b17f1aa72688c0f3eee4c88231a4a . "./code.idejs/ide-form.fasl")
(#xc4a58bd257a8351faf297a323e10bf71 . "./code.idejs/ide-find-definitions.fasl")
(#x7c76e6de17e865c86003f882a3352e9f . "./code.idejs/ide-apropos.fasl")
(#x965da270582cf1c388992f2daf660265 . "./code.idejs/ide-class-browser.fasl")
(#xe82c1da0a1ce321efd25ab610998f885 . "./code.idejs/ide-navigator.fasl")
(#x2ff93132432409174bbd982eb0e7d398 . "./code.idejs/ide-clipboard.fasl")
(#x07927463811ea219ff0f13ed45b8a6c5 . "./code.idejs/ide-acache.fasl")
(#x14ed4d61c634568ea7d989365d4da4fb . "./code.idejs/ide-keyshort.fasl")
(#x069095f8bedd38bfd1d92e16b14efee0 . "./code.idejs/ide-package-list.fasl")
(#xf4c109146539befe47cd14ffa545edd1 . "./code.idejs/ide-dev.fasl")
(#x785b009207cd19fe54c93fc535e484ec . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
